[MOAB-dev] r2603 - in MOAB/trunk/tools/iMesh: . SIDL SIDL/mserver

kraftche at mcs.anl.gov kraftche at mcs.anl.gov
Fri Jan 30 09:42:40 CST 2009


Author: kraftche
Date: 2009-01-30 09:42:34 -0600 (Fri, 30 Jan 2009)
New Revision: 2603

Modified:
   MOAB/trunk/tools/iMesh/SIDL/iMesh.sidl
   MOAB/trunk/tools/iMesh/SIDL/mserver/iMesh_SIDL_MeshSidl_Impl.cc
   MOAB/trunk/tools/iMesh/iMesh.h
   MOAB/trunk/tools/iMesh/iMesh_MOAB.cpp
Log:
o Add missing implementation of iMesh_setGeometricDimension
o Remove in_entity_set argument from iMesh_getAdjEntities


Modified: MOAB/trunk/tools/iMesh/SIDL/iMesh.sidl
===================================================================
--- MOAB/trunk/tools/iMesh/SIDL/iMesh.sidl	2009-01-29 23:10:13 UTC (rev 2602)
+++ MOAB/trunk/tools/iMesh/SIDL/iMesh.sidl	2009-01-30 15:42:34 UTC (rev 2603)
@@ -110,9 +110,7 @@
                            inout array<opaque> adj_entity_handles, 
                            out int adj_entity_handles_size,
                            inout array<int> offset,
-                           out int offset_size,
-                           inout array<int> in_entity_set,
-                           out int in_entity_set_size) throws iBase.Error;
+                           out int offset_size) throws iBase.Error;
 
       void getAdjEntIndices( in opaque entity_set_handle,
                              in EntityType entity_type_requestor,

Modified: MOAB/trunk/tools/iMesh/SIDL/mserver/iMesh_SIDL_MeshSidl_Impl.cc
===================================================================
--- MOAB/trunk/tools/iMesh/SIDL/mserver/iMesh_SIDL_MeshSidl_Impl.cc	2009-01-29 23:10:13 UTC (rev 2602)
+++ MOAB/trunk/tools/iMesh/SIDL/mserver/iMesh_SIDL_MeshSidl_Impl.cc	2009-01-30 15:42:34 UTC (rev 2603)
@@ -3,15 +3,15 @@
 // Symbol:        iMesh_SIDL.MeshSidl-v0.2
 // Symbol Type:   class
 // Babel Version: 0.10.10
-// sidl Created:  20090120 19:02:01 CST
-// Generated:     20090120 19:02:03 CST
+// sidl Created:  20090130 09:34:06 CST
+// Generated:     20090130 09:34:08 CST
 // Description:   Server-side implementation for iMesh_SIDL.MeshSidl
 // 
 // WARNING: Automatically generated; only changes within splicers preserved
 // 
 // babel-version = 0.10.10
 // source-line   = 5
-// source-url    = file:/home/jason/moab/newimesh/src/tools/iMesh/SIDL/iMesh_SIDL.sidl
+// source-url    = file:/home/jason/moab/clean/sidl/tools/iMesh/SIDL/../../../../src/tools/iMesh/SIDL/iMesh_SIDL.sidl
 // 
 #include "iMesh_SIDL_MeshSidl_Impl.hh"
 
@@ -1575,10 +1575,7 @@
   /* in */ ::iBase::EntityType entity_type_requested,
   /* inout */ ::sidl::array<void*>& adj_entity_handles,
   /* out */ int32_t& adj_entity_handles_size,
-  /* inout */ ::sidl::array<int32_t>& offset,
-  /* out */ int32_t& offset_size,
-  /* inout */ ::sidl::array<int32_t>& in_entity_set,
-  /* out */ int32_t& in_entity_set_size ) 
+  /* inout */ ::sidl::array<int32_t>& offset ) 
 throw ( 
   ::iBase::Error
 ){
@@ -1587,7 +1584,6 @@
   
   CREATE_TEMP_EH_ARRAY(adj_entity_handles);
   CREATE_TEMP_ARRAY(int32_t, offset);
-  CREATE_TEMP_ARRAY(int32_t, in_entity_set);
   
   iMesh_getAdjEntities (imeshInstance, reinterpret_cast<iBase_EntitySetHandle>(entity_set), 
                         (iBase_EntityType)entity_type_requestor,
@@ -1595,13 +1591,12 @@
                         (iBase_EntityType)entity_type_requested,
                         TEMP_ARRAY_INOUT(adj_entity_handles),
                         TEMP_ARRAY_INOUT(offset),
-                        TEMP_ARRAY_INOUT(in_entity_set), &imeshError);
+                        &imeshError);
   PROCESS_ERROR;
 
 
   ASSIGN_TYPED_ARRAY(void*, adj_entity_handles);
   ASSIGN_TYPED_ARRAY(int32_t, offset);
-  ASSIGN_TYPED_ARRAY(int32_t, in_entity_set);
   // DO-NOT-DELETE splicer.end(iMesh_SIDL.MeshSidl.getAdjEntities)
 }
 

Modified: MOAB/trunk/tools/iMesh/iMesh.h
===================================================================
--- MOAB/trunk/tools/iMesh/iMesh_MOAB.cpp	2009-01-29 23:10:13 UTC (rev 2602)
+++ MOAB/trunk/tools/iMesh/iMesh_MOAB.cpp	2009-01-30 15:42:34 UTC (rev 2603)
@@ -375,6 +375,13 @@
     RETURN(iBase_SUCCESS);
   }
 
+  void iMesh_setGeometricDimension(iMesh_Instance instance,
+                                   int geom_dim, int *err)
+  {
+    MBErrorCode rval = MBI->set_dimension(geom_dim);
+    RETURN((MB_SUCCESS == rval ? iBase_SUCCESS : iBase_FAILURE));
+  }
+
   void iMesh_getDfltStorage(iMesh_Instance instance,
                             int *order, int *err)
   {
@@ -710,10 +717,8 @@
                             /*out*/ int* adj_entity_handles_size,
                             /*inout*/ int** offset,
                             /*inout*/ int* offset_allocated,
-                            /*out*/ int* offset_size,
-                            /*inout*/ int** in_entity_set,
-                            /*inout*/ int* in_entity_set_allocated,
-                            /*out*/ int* in_entity_set_size, int *err) 
+                            /*inout*/ int* offset_size,
+                            /*out*/ int *err) 
   {
     MBEntityHandle in_set = ENTITY_HANDLE(entity_set_handle);
     MBRange entities;
@@ -743,7 +748,7 @@
 
     if (num_entities == 0) 
     {
-      *adj_entity_handles_size = *offset_size = *in_entity_set_size = 0;
+      *adj_entity_handles_size = *offset_size = 0;
       RETURN(iBase_ERROR_MAP[result]);
     }
 
@@ -778,9 +783,6 @@
     CHECK_SIZE(*offset, *offset_allocated, 
                (int)entities.size(), int, iBase_MEMORY_ALLOCATION_FAILED);
 
-    CHECK_SIZE(*in_entity_set, *in_entity_set_allocated,
-               num_sub, int, iBase_MEMORY_ALLOCATION_FAILED);
-
       // now iterate over entities
     num_sub = 0;
     int i = 0;
@@ -809,11 +811,6 @@
       for (std::vector<MBEntityHandle>::iterator vit = adj_ents.begin(); 
            vit != adj_ents.end(); vit++) {
         (*adj_entity_handles)[num_sub] = (iBase_EntityHandle)*vit;
-        if (0 == in_set || entities.find(*vit) != endr)
-          (*in_entity_set)[num_sub] = 1;
-        else
-          (*in_entity_set)[num_sub] = 0;
-
         num_sub++;
       }
 
@@ -822,8 +819,7 @@
 
     *adj_entity_handles_size = num_sub;
     *offset_size = entities.size();
-    *in_entity_set_size = num_sub;
-
+ 
     RETURN(iBase_SUCCESS);
   }
 



More information about the moab-dev mailing list
--- MOAB/trunk/tools/iMesh/iMesh.h	2009-01-29 23:10:13 UTC (rev 2602)
+++ MOAB/trunk/tools/iMesh/iMesh.h	2009-01-30 15:42:34 UTC (rev 2603)
@@ -393,10 +393,9 @@
     /**\brief  Get entities adjacent to those of requested type/topology in set or instance
      *
      * Get entities adjacent to those of requested type/topology in set or 
-     * instance.  If set is specified, also returns whether each adjacent entity 
-     * is in the set ((*in_entity_set)[i]=1 indicates that adjacent entity
-     * (*adj_entity_handles)[i] is in the specified set).  If adjacencies for 
-     * all entities of specified type or
+     * instance.  
+     *
+     * If adjacencies for all entities of specified type or
      * topology are desired, specify iMesh_ALL_TOPOLOGIES or iBase_ALL_TYPES,
      * respectively.  Types and topologies input to this function must be values
      * in the iBase_EntityType or iBase_EntityTopology enumerations, respectively.
@@ -419,12 +418,6 @@
      * \param *offset Pointer to array of offsets returned from function
      * \param *offset_allocated Pointer to allocated size of offset array
      * \param *offset_size Pointer to occupied size of offset array
-     * \param *in_entity_set Pointer to array of in_entity_set returned 
-     *        from function
-     * \param *in_entity_set_allocated Pointer to allocated size of 
-     *        in_entity_set array
-     * \param *in_entity_set_size Pointer to occupied size of in_entity_set 
-     *        array
      * \param *err Pointer to error type returned from function
      */
   void iMesh_getAdjEntities(iMesh_Instance instance,
@@ -438,9 +431,6 @@
                             /*inout*/ int** offset,
                             /*inout*/ int* offset_allocated,
                             /*out*/ int* offset_size,
-                            /*inout*/ int** in_entity_set,
-                            /*inout*/ int* in_entity_set_allocated,
-                            /*out*/ int* in_entity_set_size, 
                             /*out*/ int *err);
 
     /**\brief Initialize an array iterator over specified entity type, topology, and 
@@ -604,8 +594,8 @@
  * \param instance iMesh instance for this call
  * \param entity_handles Entities from which adjacencies are requested
  * \param entity_handles_size Number of entities whose adjacencies are requested
  * \param bridge_dimension Bridge dimension for 2nd order adjacencies
  * \param to_dimension Dimension of adjacent entities returned
  * \param adj_entity_handles Adjacent entities
  * \param adj_entity_handles_allocated Allocated size of returned array
  * \param adj_entity_handles_size Occupied size of returned array
@@ -618,7 +608,7 @@
   void iMesh_getEntArr2ndAdj( iMesh_Instance instance,
                               iBase_EntityHandle const* entity_handles,
                               int entity_handles_size,
-                              int order_adjacent_key,
+                              int bridge_entity_type,
                               int requested_entity_type,
                               iBase_EntityHandle** adj_entity_handles,
                               int* adj_entity_handles_allocated,
@@ -870,8 +860,8 @@
      * \param *err Pointer to error type returned from function
      */
   void iMesh_isEntContained(iMesh_Instance instance,
-                            /*in*/ const iBase_EntitySetHandle containing_entity_set,
-                            /*in*/ const iBase_EntityHandle contained_entity,
+                            /*in*/ iBase_EntitySetHandle containing_entity_set,
+                            /*in*/ iBase_EntityHandle contained_entity,
                             /*out*/ int *is_contained,
                             /*out*/ int *err);
 
@@ -1967,8 +1957,8 @@
  * specified "to" dimension.
  * \param instance iMesh instance for this call
  * \param entity_handle Entity from which adjacencies are requested
  * \param bridge_dimension Bridge dimension for 2nd order adjacencies
  * \param to_dimension Dimension of adjacent entities returned
  * \param adjacent_entities Adjacent entities
  * \param adjacent_entities_allocated Allocated size of returned array
  * \param adjacent_entities_size Occupied size of returned array
@@ -1976,7 +1966,7 @@
  */
   void iMesh_getEnt2ndAdj( iMesh_Instance instance,
                            iBase_EntityHandle entity_handle,
-                           int order_adjacent_key,
+                           int bridge_entity_type,
                            int requested_entity_type,
                            iBase_EntityHandle** adjacent_entities,
                            int* adjacent_entities_allocated,
@@ -604,8 +594,8 @@
  * \param entity_handles Entities from which adjacencies are requested
  * \param entity_handles_size Number of entities whose adjacencies are requested
- * \param bridge_dimension Bridge dimension for 2nd order adjacencies
- * \param to_dimension Dimension of adjacent entities returned
+ * \param bridge_entity_type  Type of bridge entity for 2nd order adjacencies
+ * \param requested_entity_type Type of adjacent entities returned
  * \param adj_entity_handles Adjacent entities
  * \param adj_entity_handles_allocated Allocated size of returned array
@@ -1967,8 +1957,8 @@
  * \param instance iMesh instance for this call
  * \param entity_handle Entity from which adjacencies are requested
- * \param bridge_dimension Bridge dimension for 2nd order adjacencies
- * \param to_dimension Dimension of adjacent entities returned
+ * \param bridge_entity_type  Type of bridge entity for 2nd order adjacencies
+ * \param requested_entity_type Type of adjacent entities returned
  * \param adjacent_entities Adjacent entities
  * \param adjacent_entities_allocated Allocated size of returned array

Modified: MOAB/trunk/tools/iMesh/iMesh_MOAB.cpp
===================================================================